import React, { createRef, forwardRef, useEffect, useImperativeHandle, useRef, useState } from 'react';
import { renderToBody } from '../../utils/render-to-body';
import { ImageViewer, MultiImageViewer } from './image-viewer';
import { renderImperatively } from '../../utils/render-imperatively';
const handlerSet = new Set();
export function showImageViewer(props) {
  clearImageViewer();
  const handler = renderImperatively(React.createElement(ImageViewer, Object.assign({}, props, {
    afterClose: () => {
      var _a;

      handlerSet.delete(handler);
      (_a = props.afterClose) === null || _a === void 0 ? void 0 : _a.call(props);
    }
  })));
  handlerSet.add(handler);
  return handler;
}
export function showMultiImageViewer(props) {
  clearImageViewer();
  const Wrapper = forwardRef((_, ref) => {
    const [visible, setVisible] = useState(false);
    const closedRef = useRef(false);
    useEffect(() => {
      if (!closedRef.current) {
        setVisible(true);
      } else {
        handleAfterClose();
      }
    }, []);

    function handleClose() {
      var _a;

      closedRef.current = true;
      (_a = props.onClose) === null || _a === void 0 ? void 0 : _a.call(props);
      setVisible(false);
    }

    useImperativeHandle(ref, () => ({
      close: handleClose
    }));

    function handleAfterClose() {
      var _a;

      (_a = props.afterClose) === null || _a === void 0 ? void 0 : _a.call(props);
      unmount();
      handlerSet.delete(handler);
    }

    return React.createElement(MultiImageViewer, Object.assign({}, props, {
      visible: visible,
      onClose: handleClose,
      afterClose: handleAfterClose
    }));
  });
  const ref = createRef();
  const unmount = renderToBody(React.createElement(Wrapper, {
    ref: ref
  }));
  const handler = {
    close: () => {
      var _a;

      (_a = ref.current) === null || _a === void 0 ? void 0 : _a.close();
    }
  };
  handlerSet.add(handler);
  return handler;
}
export function clearImageViewer() {
  handlerSet.forEach(handler => {
    handler.close();
  });
  handlerSet.clear();
}
export const getH = () => {
  console.log(handlerSet);
};